@@ -1,7 +1,7 @@
 package Perinci::Sub::To::POD;
 
-our $DATE = '2017-02-24'; # DATE
-our $VERSION = '0.83'; # VERSION
+our $DATE = '2017-02-27'; # DATE
+our $VERSION = '0.84'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -206,7 +206,8 @@ sub after_gen_doc {
                     $max_lines += 7; # to accomodate extra lines associated with envelopes and array enclosures
                     if (@resdump > $max_lines) {
                         my $n = int($max_lines/2);
-                        splice @resdump, $n, (@resdump - $max_lines + 1), "# ...snipped for brevity...\n";
+                        my $num_remove = @resdump - $max_lines + 1;
+                        splice @resdump, $n, $num_remove, "# ...snipped ".($num_remove > 1 ? "$num_remove lines" : "1 line")." for brevity...\n";
                         $resdump = join("", @resdump);
                     }
                 }
@@ -424,7 +425,7 @@ Perinci::Sub::To::POD - Generate POD documentation from Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.83 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2017-02-24.
+This document describes version 0.84 of Perinci::Sub::To::POD (from Perl distribution Perinci-To-Doc), released on 2017-02-27.
 
 =head1 SYNOPSIS
 
@@ -442,7 +443,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-To
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-To-Doc>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-To-Doc>.
 
 =head1 BUGS
 
